# spoonacular - the C# library for the spoonacular API

The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.

Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.

This C# SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.1
- SDK version: 1.1.1
- Build package: org.openapitools.codegen.languages.CSharpClientCodegen
    For more information, please visit [https://spoonacular.com/contact](https://spoonacular.com/contact)

<a id="frameworks-supported"></a>
## Frameworks supported

<a id="dependencies"></a>
## Dependencies

- [RestSharp](https://www.nuget.org/packages/RestSharp) - 106.13.0 or later
- [Json.NET](https://www.nuget.org/packages/Newtonsoft.Json/) - 13.0.2 or later
- [JsonSubTypes](https://www.nuget.org/packages/JsonSubTypes/) - 1.8.0 or later
- [System.ComponentModel.Annotations](https://www.nuget.org/packages/System.ComponentModel.Annotations) - 5.0.0 or later

The DLLs included in the package may not be the latest version. We recommend using [NuGet](https://docs.nuget.org/consume/installing-nuget) to obtain the latest version of the packages:
```
Install-Package RestSharp
Install-Package Newtonsoft.Json
Install-Package JsonSubTypes
Install-Package System.ComponentModel.Annotations
```

NOTE: RestSharp versions greater than 105.1.0 have a bug which causes file uploads to fail. See [RestSharp#742](https://github.com/restsharp/RestSharp/issues/742).
NOTE: RestSharp for .Net Core creates a new socket for each api call, which can lead to a socket exhaustion problem. See [RestSharp#1406](https://github.com/restsharp/RestSharp/issues/1406).

<a id="installation"></a>
## Installation
Run the following command to generate the DLL
- [Mac/Linux] `/bin/sh build.sh`
- [Windows] `build.bat`

Then include the DLL (under the `bin` folder) in the C# project, and use the namespaces:
```csharp
using spoonacular.Api;
using spoonacular.Client;
using spoonacular.Model;
```
<a id="packaging"></a>
## Packaging

A `.nuspec` is included with the project. You can follow the Nuget quickstart to [create](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#create-the-package) and [publish](https://docs.microsoft.com/en-us/nuget/quickstart/create-and-publish-a-package#publish-the-package) packages.

This `.nuspec` uses placeholders from the `.csproj`, so build the `.csproj` directly:

```
nuget pack -Build -OutputDirectory out spoonacular.csproj
```

Then, publish to a [local feed](https://docs.microsoft.com/en-us/nuget/hosting-packages/local-feeds) or [other host](https://docs.microsoft.com/en-us/nuget/hosting-packages/overview) and consume the new package via Nuget as usual.

<a id="usage"></a>
## Usage

To use the API client with a HTTP proxy, setup a `System.Net.WebProxy`
```csharp
Configuration c = new Configuration();
System.Net.WebProxy webProxy = new System.Net.WebProxy("http://myProxyUrl:80/");
webProxy.Credentials = System.Net.CredentialCache.DefaultCredentials;
c.Proxy = webProxy;
```

<a id="getting-started"></a>
## Getting Started

```csharp
using System.Collections.Generic;
using System.Diagnostics;
using spoonacular.Api;
using spoonacular.Client;
using spoonacular.Model;

namespace Example
{
    public class Example
    {
        public static void Main()
        {

            Configuration config = new Configuration();
            config.BasePath = "https://api.spoonacular.com";
            // Configure API key authorization: apiKeyScheme
            config.ApiKey.Add("x-api-key", "YOUR_API_KEY");
            // Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
            // config.ApiKeyPrefix.Add("x-api-key", "Bearer");

            var apiInstance = new DefaultApi(config);
            var analyzeRecipeRequest = new AnalyzeRecipeRequest(); // AnalyzeRecipeRequest | Example request body.
            var language = en;  // string? | The input language, either \"en\" or \"de\". (optional) 
            var includeNutrition = false;  // bool? | Whether nutrition data should be added to correctly parsed ingredients. (optional) 
            var includeTaste = false;  // bool? | Whether taste data should be added to correctly parsed ingredients. (optional) 

            try
            {
                // Analyze Recipe
                Object result = apiInstance.AnalyzeRecipe(analyzeRecipeRequest, language, includeNutrition, includeTaste);
                Debug.WriteLine(result);
            }
            catch (ApiException e)
            {
                Debug.Print("Exception when calling DefaultApi.AnalyzeRecipe: " + e.Message );
                Debug.Print("Status Code: "+ e.ErrorCode);
                Debug.Print(e.StackTrace);
            }

        }
    }
}
```

<a id="documentation-for-api-endpoints"></a>
## Documentation for API Endpoints

All URIs are relative to *https://api.spoonacular.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**AnalyzeRecipe**](docs/DefaultApi.md#analyzerecipe) | **POST** /recipes/analyze | Analyze Recipe
*DefaultApi* | [**CreateRecipeCardGet**](docs/DefaultApi.md#createrecipecardget) | **GET** /recipes/{id}/card | Create Recipe Card
*DefaultApi* | [**SearchRestaurants**](docs/DefaultApi.md#searchrestaurants) | **GET** /food/restaurants/search | Search Restaurants
*IngredientsApi* | [**AutocompleteIngredientSearch**](docs/IngredientsApi.md#autocompleteingredientsearch) | **GET** /food/ingredients/autocomplete | Autocomplete Ingredient Search
*IngredientsApi* | [**ComputeIngredientAmount**](docs/IngredientsApi.md#computeingredientamount) | **GET** /food/ingredients/{id}/amount | Compute Ingredient Amount
*IngredientsApi* | [**GetIngredientInformation**](docs/IngredientsApi.md#getingredientinformation) | **GET** /food/ingredients/{id}/information | Get Ingredient Information
*IngredientsApi* | [**GetIngredientSubstitutes**](docs/IngredientsApi.md#getingredientsubstitutes) | **GET** /food/ingredients/substitutes | Get Ingredient Substitutes
*IngredientsApi* | [**GetIngredientSubstitutesByID**](docs/IngredientsApi.md#getingredientsubstitutesbyid) | **GET** /food/ingredients/{id}/substitutes | Get Ingredient Substitutes by ID
*IngredientsApi* | [**IngredientSearch**](docs/IngredientsApi.md#ingredientsearch) | **GET** /food/ingredients/search | Ingredient Search
*IngredientsApi* | [**IngredientsByIDImage**](docs/IngredientsApi.md#ingredientsbyidimage) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*IngredientsApi* | [**MapIngredientsToGroceryProducts**](docs/IngredientsApi.md#mapingredientstogroceryproducts) | **POST** /food/ingredients/map | Map Ingredients to Grocery Products
*IngredientsApi* | [**VisualizeIngredients**](docs/IngredientsApi.md#visualizeingredients) | **POST** /recipes/visualizeIngredients | Ingredients Widget
*MealPlanningApi* | [**AddMealPlanTemplate**](docs/MealPlanningApi.md#addmealplantemplate) | **POST** /mealplanner/{username}/templates | Add Meal Plan Template
*MealPlanningApi* | [**AddToMealPlan**](docs/MealPlanningApi.md#addtomealplan) | **POST** /mealplanner/{username}/items | Add to Meal Plan
*MealPlanningApi* | [**AddToShoppingList**](docs/MealPlanningApi.md#addtoshoppinglist) | **POST** /mealplanner/{username}/shopping-list/items | Add to Shopping List
*MealPlanningApi* | [**ClearMealPlanDay**](docs/MealPlanningApi.md#clearmealplanday) | **DELETE** /mealplanner/{username}/day/{date} | Clear Meal Plan Day
*MealPlanningApi* | [**ConnectUser**](docs/MealPlanningApi.md#connectuser) | **POST** /users/connect | Connect User
*MealPlanningApi* | [**DeleteFromMealPlan**](docs/MealPlanningApi.md#deletefrommealplan) | **DELETE** /mealplanner/{username}/items/{id} | Delete from Meal Plan
*MealPlanningApi* | [**DeleteFromShoppingList**](docs/MealPlanningApi.md#deletefromshoppinglist) | **DELETE** /mealplanner/{username}/shopping-list/items/{id} | Delete from Shopping List
*MealPlanningApi* | [**DeleteMealPlanTemplate**](docs/MealPlanningApi.md#deletemealplantemplate) | **DELETE** /mealplanner/{username}/templates/{id} | Delete Meal Plan Template
*MealPlanningApi* | [**GenerateMealPlan**](docs/MealPlanningApi.md#generatemealplan) | **GET** /mealplanner/generate | Generate Meal Plan
*MealPlanningApi* | [**GenerateShoppingList**](docs/MealPlanningApi.md#generateshoppinglist) | **POST** /mealplanner/{username}/shopping-list/{start-date}/{end-date} | Generate Shopping List
*MealPlanningApi* | [**GetMealPlanTemplate**](docs/MealPlanningApi.md#getmealplantemplate) | **GET** /mealplanner/{username}/templates/{id} | Get Meal Plan Template
*MealPlanningApi* | [**GetMealPlanTemplates**](docs/MealPlanningApi.md#getmealplantemplates) | **GET** /mealplanner/{username}/templates | Get Meal Plan Templates
*MealPlanningApi* | [**GetMealPlanWeek**](docs/MealPlanningApi.md#getmealplanweek) | **GET** /mealplanner/{username}/week/{start-date} | Get Meal Plan Week
*MealPlanningApi* | [**GetShoppingList**](docs/MealPlanningApi.md#getshoppinglist) | **GET** /mealplanner/{username}/shopping-list | Get Shopping List
*MenuItemsApi* | [**AutocompleteMenuItemSearch**](docs/MenuItemsApi.md#autocompletemenuitemsearch) | **GET** /food/menuItems/suggest | Autocomplete Menu Item Search
*MenuItemsApi* | [**GetMenuItemInformation**](docs/MenuItemsApi.md#getmenuiteminformation) | **GET** /food/menuItems/{id} | Get Menu Item Information
*MenuItemsApi* | [**MenuItemNutritionByIDImage**](docs/MenuItemsApi.md#menuitemnutritionbyidimage) | **GET** /food/menuItems/{id}/nutritionWidget.png | Menu Item Nutrition by ID Image
*MenuItemsApi* | [**MenuItemNutritionLabelImage**](docs/MenuItemsApi.md#menuitemnutritionlabelimage) | **GET** /food/menuItems/{id}/nutritionLabel.png | Menu Item Nutrition Label Image
*MenuItemsApi* | [**MenuItemNutritionLabelWidget**](docs/MenuItemsApi.md#menuitemnutritionlabelwidget) | **GET** /food/menuItems/{id}/nutritionLabel | Menu Item Nutrition Label Widget
*MenuItemsApi* | [**SearchMenuItems**](docs/MenuItemsApi.md#searchmenuitems) | **GET** /food/menuItems/search | Search Menu Items
*MenuItemsApi* | [**VisualizeMenuItemNutritionByID**](docs/MenuItemsApi.md#visualizemenuitemnutritionbyid) | **GET** /food/menuItems/{id}/nutritionWidget | Menu Item Nutrition by ID Widget
*MiscApi* | [**DetectFoodInText**](docs/MiscApi.md#detectfoodintext) | **POST** /food/detect | Detect Food in Text
*MiscApi* | [**GetARandomFoodJoke**](docs/MiscApi.md#getarandomfoodjoke) | **GET** /food/jokes/random | Random Food Joke
*MiscApi* | [**GetConversationSuggests**](docs/MiscApi.md#getconversationsuggests) | **GET** /food/converse/suggest | Conversation Suggests
*MiscApi* | [**GetRandomFoodTrivia**](docs/MiscApi.md#getrandomfoodtrivia) | **GET** /food/trivia/random | Random Food Trivia
*MiscApi* | [**ImageAnalysisByURL**](docs/MiscApi.md#imageanalysisbyurl) | **GET** /food/images/analyze | Image Analysis by URL
*MiscApi* | [**ImageClassificationByURL**](docs/MiscApi.md#imageclassificationbyurl) | **GET** /food/images/classify | Image Classification by URL
*MiscApi* | [**SearchAllFood**](docs/MiscApi.md#searchallfood) | **GET** /food/search | Search All Food
*MiscApi* | [**SearchCustomFoods**](docs/MiscApi.md#searchcustomfoods) | **GET** /food/customFoods/search | Search Custom Foods
*MiscApi* | [**SearchFoodVideos**](docs/MiscApi.md#searchfoodvideos) | **GET** /food/videos/search | Search Food Videos
*MiscApi* | [**SearchSiteContent**](docs/MiscApi.md#searchsitecontent) | **GET** /food/site/search | Search Site Content
*MiscApi* | [**TalkToChatbot**](docs/MiscApi.md#talktochatbot) | **GET** /food/converse | Talk to Chatbot
*ProductsApi* | [**AutocompleteProductSearch**](docs/ProductsApi.md#autocompleteproductsearch) | **GET** /food/products/suggest | Autocomplete Product Search
*ProductsApi* | [**ClassifyGroceryProduct**](docs/ProductsApi.md#classifygroceryproduct) | **POST** /food/products/classify | Classify Grocery Product
*ProductsApi* | [**ClassifyGroceryProductBulk**](docs/ProductsApi.md#classifygroceryproductbulk) | **POST** /food/products/classifyBatch | Classify Grocery Product Bulk
*ProductsApi* | [**GetComparableProducts**](docs/ProductsApi.md#getcomparableproducts) | **GET** /food/products/upc/{upc}/comparable | Get Comparable Products
*ProductsApi* | [**GetProductInformation**](docs/ProductsApi.md#getproductinformation) | **GET** /food/products/{id} | Get Product Information
*ProductsApi* | [**ProductNutritionByIDImage**](docs/ProductsApi.md#productnutritionbyidimage) | **GET** /food/products/{id}/nutritionWidget.png | Product Nutrition by ID Image
*ProductsApi* | [**ProductNutritionLabelImage**](docs/ProductsApi.md#productnutritionlabelimage) | **GET** /food/products/{id}/nutritionLabel.png | Product Nutrition Label Image
*ProductsApi* | [**ProductNutritionLabelWidget**](docs/ProductsApi.md#productnutritionlabelwidget) | **GET** /food/products/{id}/nutritionLabel | Product Nutrition Label Widget
*ProductsApi* | [**SearchGroceryProducts**](docs/ProductsApi.md#searchgroceryproducts) | **GET** /food/products/search | Search Grocery Products
*ProductsApi* | [**SearchGroceryProductsByUPC**](docs/ProductsApi.md#searchgroceryproductsbyupc) | **GET** /food/products/upc/{upc} | Search Grocery Products by UPC
*ProductsApi* | [**VisualizeProductNutritionByID**](docs/ProductsApi.md#visualizeproductnutritionbyid) | **GET** /food/products/{id}/nutritionWidget | Product Nutrition by ID Widget
*RecipesApi* | [**AnalyzeARecipeSearchQuery**](docs/RecipesApi.md#analyzearecipesearchquery) | **GET** /recipes/queries/analyze | Analyze a Recipe Search Query
*RecipesApi* | [**AnalyzeRecipeInstructions**](docs/RecipesApi.md#analyzerecipeinstructions) | **POST** /recipes/analyzeInstructions | Analyze Recipe Instructions
*RecipesApi* | [**AutocompleteRecipeSearch**](docs/RecipesApi.md#autocompleterecipesearch) | **GET** /recipes/autocomplete | Autocomplete Recipe Search
*RecipesApi* | [**ClassifyCuisine**](docs/RecipesApi.md#classifycuisine) | **POST** /recipes/cuisine | Classify Cuisine
*RecipesApi* | [**ComputeGlycemicLoad**](docs/RecipesApi.md#computeglycemicload) | **POST** /food/ingredients/glycemicLoad | Compute Glycemic Load
*RecipesApi* | [**ConvertAmounts**](docs/RecipesApi.md#convertamounts) | **GET** /recipes/convert | Convert Amounts
*RecipesApi* | [**CreateRecipeCard**](docs/RecipesApi.md#createrecipecard) | **POST** /recipes/visualizeRecipe | Create Recipe Card
*RecipesApi* | [**EquipmentByIDImage**](docs/RecipesApi.md#equipmentbyidimage) | **GET** /recipes/{id}/equipmentWidget.png | Equipment by ID Image
*RecipesApi* | [**ExtractRecipeFromWebsite**](docs/RecipesApi.md#extractrecipefromwebsite) | **GET** /recipes/extract | Extract Recipe from Website
*RecipesApi* | [**GetAnalyzedRecipeInstructions**](docs/RecipesApi.md#getanalyzedrecipeinstructions) | **GET** /recipes/{id}/analyzedInstructions | Get Analyzed Recipe Instructions
*RecipesApi* | [**GetRandomRecipes**](docs/RecipesApi.md#getrandomrecipes) | **GET** /recipes/random | Get Random Recipes
*RecipesApi* | [**GetRecipeEquipmentByID**](docs/RecipesApi.md#getrecipeequipmentbyid) | **GET** /recipes/{id}/equipmentWidget.json | Equipment by ID
*RecipesApi* | [**GetRecipeInformation**](docs/RecipesApi.md#getrecipeinformation) | **GET** /recipes/{id}/information | Get Recipe Information
*RecipesApi* | [**GetRecipeInformationBulk**](docs/RecipesApi.md#getrecipeinformationbulk) | **GET** /recipes/informationBulk | Get Recipe Information Bulk
*RecipesApi* | [**GetRecipeIngredientsByID**](docs/RecipesApi.md#getrecipeingredientsbyid) | **GET** /recipes/{id}/ingredientWidget.json | Ingredients by ID
*RecipesApi* | [**GetRecipeNutritionWidgetByID**](docs/RecipesApi.md#getrecipenutritionwidgetbyid) | **GET** /recipes/{id}/nutritionWidget.json | Nutrition by ID
*RecipesApi* | [**GetRecipePriceBreakdownByID**](docs/RecipesApi.md#getrecipepricebreakdownbyid) | **GET** /recipes/{id}/priceBreakdownWidget.json | Price Breakdown by ID
*RecipesApi* | [**GetRecipeTasteByID**](docs/RecipesApi.md#getrecipetastebyid) | **GET** /recipes/{id}/tasteWidget.json | Taste by ID
*RecipesApi* | [**GetSimilarRecipes**](docs/RecipesApi.md#getsimilarrecipes) | **GET** /recipes/{id}/similar | Get Similar Recipes
*RecipesApi* | [**GuessNutritionByDishName**](docs/RecipesApi.md#guessnutritionbydishname) | **GET** /recipes/guessNutrition | Guess Nutrition by Dish Name
*RecipesApi* | [**IngredientsByIDImage**](docs/RecipesApi.md#ingredientsbyidimage) | **GET** /recipes/{id}/ingredientWidget.png | Ingredients by ID Image
*RecipesApi* | [**ParseIngredients**](docs/RecipesApi.md#parseingredients) | **POST** /recipes/parseIngredients | Parse Ingredients
*RecipesApi* | [**PriceBreakdownByIDImage**](docs/RecipesApi.md#pricebreakdownbyidimage) | **GET** /recipes/{id}/priceBreakdownWidget.png | Price Breakdown by ID Image
*RecipesApi* | [**QuickAnswer**](docs/RecipesApi.md#quickanswer) | **GET** /recipes/quickAnswer | Quick Answer
*RecipesApi* | [**RecipeNutritionByIDImage**](docs/RecipesApi.md#recipenutritionbyidimage) | **GET** /recipes/{id}/nutritionWidget.png | Recipe Nutrition by ID Image
*RecipesApi* | [**RecipeNutritionLabelImage**](docs/RecipesApi.md#recipenutritionlabelimage) | **GET** /recipes/{id}/nutritionLabel.png | Recipe Nutrition Label Image
*RecipesApi* | [**RecipeNutritionLabelWidget**](docs/RecipesApi.md#recipenutritionlabelwidget) | **GET** /recipes/{id}/nutritionLabel | Recipe Nutrition Label Widget
*RecipesApi* | [**RecipeTasteByIDImage**](docs/RecipesApi.md#recipetastebyidimage) | **GET** /recipes/{id}/tasteWidget.png | Recipe Taste by ID Image
*RecipesApi* | [**SearchRecipes**](docs/RecipesApi.md#searchrecipes) | **GET** /recipes/complexSearch | Search Recipes
*RecipesApi* | [**SearchRecipesByIngredients**](docs/RecipesApi.md#searchrecipesbyingredients) | **GET** /recipes/findByIngredients | Search Recipes by Ingredients
*RecipesApi* | [**SearchRecipesByNutrients**](docs/RecipesApi.md#searchrecipesbynutrients) | **GET** /recipes/findByNutrients | Search Recipes by Nutrients
*RecipesApi* | [**SummarizeRecipe**](docs/RecipesApi.md#summarizerecipe) | **GET** /recipes/{id}/summary | Summarize Recipe
*RecipesApi* | [**VisualizeEquipment**](docs/RecipesApi.md#visualizeequipment) | **POST** /recipes/visualizeEquipment | Equipment Widget
*RecipesApi* | [**VisualizePriceBreakdown**](docs/RecipesApi.md#visualizepricebreakdown) | **POST** /recipes/visualizePriceEstimator | Price Breakdown Widget
*RecipesApi* | [**VisualizeRecipeEquipmentByID**](docs/RecipesApi.md#visualizerecipeequipmentbyid) | **GET** /recipes/{id}/equipmentWidget | Equipment by ID Widget
*RecipesApi* | [**VisualizeRecipeIngredientsByID**](docs/RecipesApi.md#visualizerecipeingredientsbyid) | **GET** /recipes/{id}/ingredientWidget | Ingredients by ID Widget
*RecipesApi* | [**VisualizeRecipeNutrition**](docs/RecipesApi.md#visualizerecipenutrition) | **POST** /recipes/visualizeNutrition | Recipe Nutrition Widget
*RecipesApi* | [**VisualizeRecipeNutritionByID**](docs/RecipesApi.md#visualizerecipenutritionbyid) | **GET** /recipes/{id}/nutritionWidget | Recipe Nutrition by ID Widget
*RecipesApi* | [**VisualizeRecipePriceBreakdownByID**](docs/RecipesApi.md#visualizerecipepricebreakdownbyid) | **GET** /recipes/{id}/priceBreakdownWidget | Price Breakdown by ID Widget
*RecipesApi* | [**VisualizeRecipeTaste**](docs/RecipesApi.md#visualizerecipetaste) | **POST** /recipes/visualizeTaste | Recipe Taste Widget
*RecipesApi* | [**VisualizeRecipeTasteByID**](docs/RecipesApi.md#visualizerecipetastebyid) | **GET** /recipes/{id}/tasteWidget | Recipe Taste by ID Widget
*WineApi* | [**GetDishPairingForWine**](docs/WineApi.md#getdishpairingforwine) | **GET** /food/wine/dishes | Dish Pairing for Wine
*WineApi* | [**GetWineDescription**](docs/WineApi.md#getwinedescription) | **GET** /food/wine/description | Wine Description
*WineApi* | [**GetWinePairing**](docs/WineApi.md#getwinepairing) | **GET** /food/wine/pairing | Wine Pairing
*WineApi* | [**GetWineRecommendation**](docs/WineApi.md#getwinerecommendation) | **GET** /food/wine/recommendation | Wine Recommendation


<a id="documentation-for-models"></a>
## Documentation for Models

 - [Model.AddMealPlanTemplate200Response](docs/AddMealPlanTemplate200Response.md)
 - [Model.AddMealPlanTemplate200ResponseItemsInner](docs/AddMealPlanTemplate200ResponseItemsInner.md)
 - [Model.AddMealPlanTemplate200ResponseItemsInnerValue](docs/AddMealPlanTemplate200ResponseItemsInnerValue.md)
 - [Model.AddToMealPlanRequest](docs/AddToMealPlanRequest.md)
 - [Model.AddToMealPlanRequest1](docs/AddToMealPlanRequest1.md)
 - [Model.AddToMealPlanRequest1Value](docs/AddToMealPlanRequest1Value.md)
 - [Model.AddToMealPlanRequest1ValueIngredientsInner](docs/AddToMealPlanRequest1ValueIngredientsInner.md)
 - [Model.AddToShoppingListRequest](docs/AddToShoppingListRequest.md)
 - [Model.AnalyzeARecipeSearchQuery200Response](docs/AnalyzeARecipeSearchQuery200Response.md)
 - [Model.AnalyzeARecipeSearchQuery200ResponseDishesInner](docs/AnalyzeARecipeSearchQuery200ResponseDishesInner.md)
 - [Model.AnalyzeARecipeSearchQuery200ResponseIngredientsInner](docs/AnalyzeARecipeSearchQuery200ResponseIngredientsInner.md)
 - [Model.AnalyzeRecipeInstructions200Response](docs/AnalyzeRecipeInstructions200Response.md)
 - [Model.AnalyzeRecipeInstructions200ResponseIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseIngredientsInner.md)
 - [Model.AnalyzeRecipeInstructions200ResponseParsedInstructionsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [Model.AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [Model.AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/AnalyzeRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [Model.AnalyzeRecipeRequest](docs/AnalyzeRecipeRequest.md)
 - [Model.AnalyzeRecipeRequest1](docs/AnalyzeRecipeRequest1.md)
 - [Model.AutocompleteIngredientSearch200ResponseInner](docs/AutocompleteIngredientSearch200ResponseInner.md)
 - [Model.AutocompleteMenuItemSearch200Response](docs/AutocompleteMenuItemSearch200Response.md)
 - [Model.AutocompleteProductSearch200Response](docs/AutocompleteProductSearch200Response.md)
 - [Model.AutocompleteProductSearch200ResponseResultsInner](docs/AutocompleteProductSearch200ResponseResultsInner.md)
 - [Model.AutocompleteRecipeSearch200ResponseInner](docs/AutocompleteRecipeSearch200ResponseInner.md)
 - [Model.ClassifyCuisine200Response](docs/ClassifyCuisine200Response.md)
 - [Model.ClassifyGroceryProduct200Response](docs/ClassifyGroceryProduct200Response.md)
 - [Model.ClassifyGroceryProductBulk200ResponseInner](docs/ClassifyGroceryProductBulk200ResponseInner.md)
 - [Model.ClassifyGroceryProductBulkRequestInner](docs/ClassifyGroceryProductBulkRequestInner.md)
 - [Model.ClassifyGroceryProductRequest](docs/ClassifyGroceryProductRequest.md)
 - [Model.ClearMealPlanDayRequest](docs/ClearMealPlanDayRequest.md)
 - [Model.ComputeGlycemicLoad200Response](docs/ComputeGlycemicLoad200Response.md)
 - [Model.ComputeGlycemicLoad200ResponseIngredientsInner](docs/ComputeGlycemicLoad200ResponseIngredientsInner.md)
 - [Model.ComputeGlycemicLoadRequest](docs/ComputeGlycemicLoadRequest.md)
 - [Model.ComputeIngredientAmount200Response](docs/ComputeIngredientAmount200Response.md)
 - [Model.ConnectUser200Response](docs/ConnectUser200Response.md)
 - [Model.ConnectUserRequest](docs/ConnectUserRequest.md)
 - [Model.ConvertAmounts200Response](docs/ConvertAmounts200Response.md)
 - [Model.CreateRecipeCard200Response](docs/CreateRecipeCard200Response.md)
 - [Model.DeleteFromMealPlanRequest](docs/DeleteFromMealPlanRequest.md)
 - [Model.DetectFoodInText200Response](docs/DetectFoodInText200Response.md)
 - [Model.DetectFoodInText200ResponseAnnotationsInner](docs/DetectFoodInText200ResponseAnnotationsInner.md)
 - [Model.GenerateMealPlan200Response](docs/GenerateMealPlan200Response.md)
 - [Model.GenerateMealPlan200ResponseNutrients](docs/GenerateMealPlan200ResponseNutrients.md)
 - [Model.GenerateShoppingList200Response](docs/GenerateShoppingList200Response.md)
 - [Model.GenerateShoppingListRequest](docs/GenerateShoppingListRequest.md)
 - [Model.GetARandomFoodJoke200Response](docs/GetARandomFoodJoke200Response.md)
 - [Model.GetAnalyzedRecipeInstructions200Response](docs/GetAnalyzedRecipeInstructions200Response.md)
 - [Model.GetAnalyzedRecipeInstructions200ResponseIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseIngredientsInner.md)
 - [Model.GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInner.md)
 - [Model.GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInner.md)
 - [Model.GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner](docs/GetAnalyzedRecipeInstructions200ResponseParsedInstructionsInnerStepsInnerIngredientsInner.md)
 - [Model.GetComparableProducts200Response](docs/GetComparableProducts200Response.md)
 - [Model.GetComparableProducts200ResponseComparableProducts](docs/GetComparableProducts200ResponseComparableProducts.md)
 - [Model.GetComparableProducts200ResponseComparableProductsProteinInner](docs/GetComparableProducts200ResponseComparableProductsProteinInner.md)
 - [Model.GetConversationSuggests200Response](docs/GetConversationSuggests200Response.md)
 - [Model.GetConversationSuggests200ResponseSuggests](docs/GetConversationSuggests200ResponseSuggests.md)
 - [Model.GetConversationSuggests200ResponseSuggestsInner](docs/GetConversationSuggests200ResponseSuggestsInner.md)
 - [Model.GetDishPairingForWine200Response](docs/GetDishPairingForWine200Response.md)
 - [Model.GetIngredientInformation200Response](docs/GetIngredientInformation200Response.md)
 - [Model.GetIngredientInformation200ResponseNutrition](docs/GetIngredientInformation200ResponseNutrition.md)
 - [Model.GetIngredientSubstitutes200Response](docs/GetIngredientSubstitutes200Response.md)
 - [Model.GetMealPlanTemplate200Response](docs/GetMealPlanTemplate200Response.md)
 - [Model.GetMealPlanTemplate200ResponseDaysInner](docs/GetMealPlanTemplate200ResponseDaysInner.md)
 - [Model.GetMealPlanTemplate200ResponseDaysInnerItemsInner](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInner.md)
 - [Model.GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanTemplate200ResponseDaysInnerItemsInnerValue.md)
 - [Model.GetMealPlanTemplates200Response](docs/GetMealPlanTemplates200Response.md)
 - [Model.GetMealPlanWeek200Response](docs/GetMealPlanWeek200Response.md)
 - [Model.GetMealPlanWeek200ResponseDaysInner](docs/GetMealPlanWeek200ResponseDaysInner.md)
 - [Model.GetMealPlanWeek200ResponseDaysInnerItemsInner](docs/GetMealPlanWeek200ResponseDaysInnerItemsInner.md)
 - [Model.GetMealPlanWeek200ResponseDaysInnerItemsInnerValue](docs/GetMealPlanWeek200ResponseDaysInnerItemsInnerValue.md)
 - [Model.GetMealPlanWeek200ResponseDaysInnerNutritionSummary](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummary.md)
 - [Model.GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner](docs/GetMealPlanWeek200ResponseDaysInnerNutritionSummaryNutrientsInner.md)
 - [Model.GetMenuItemInformation200Response](docs/GetMenuItemInformation200Response.md)
 - [Model.GetProductInformation200Response](docs/GetProductInformation200Response.md)
 - [Model.GetProductInformation200ResponseIngredientsInner](docs/GetProductInformation200ResponseIngredientsInner.md)
 - [Model.GetRandomFoodTrivia200Response](docs/GetRandomFoodTrivia200Response.md)
 - [Model.GetRandomRecipes200Response](docs/GetRandomRecipes200Response.md)
 - [Model.GetRandomRecipes200ResponseRecipesInner](docs/GetRandomRecipes200ResponseRecipesInner.md)
 - [Model.GetRecipeEquipmentByID200Response](docs/GetRecipeEquipmentByID200Response.md)
 - [Model.GetRecipeEquipmentByID200ResponseEquipmentInner](docs/GetRecipeEquipmentByID200ResponseEquipmentInner.md)
 - [Model.GetRecipeInformation200Response](docs/GetRecipeInformation200Response.md)
 - [Model.GetRecipeInformation200ResponseExtendedIngredientsInner](docs/GetRecipeInformation200ResponseExtendedIngredientsInner.md)
 - [Model.GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasures.md)
 - [Model.GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric](docs/GetRecipeInformation200ResponseExtendedIngredientsInnerMeasuresMetric.md)
 - [Model.GetRecipeInformation200ResponseWinePairing](docs/GetRecipeInformation200ResponseWinePairing.md)
 - [Model.GetRecipeInformation200ResponseWinePairingProductMatchesInner](docs/GetRecipeInformation200ResponseWinePairingProductMatchesInner.md)
 - [Model.GetRecipeInformationBulk200ResponseInner](docs/GetRecipeInformationBulk200ResponseInner.md)
 - [Model.GetRecipeIngredientsByID200Response](docs/GetRecipeIngredientsByID200Response.md)
 - [Model.GetRecipeIngredientsByID200ResponseIngredientsInner](docs/GetRecipeIngredientsByID200ResponseIngredientsInner.md)
 - [Model.GetRecipeNutritionWidgetByID200Response](docs/GetRecipeNutritionWidgetByID200Response.md)
 - [Model.GetRecipeNutritionWidgetByID200ResponseBadInner](docs/GetRecipeNutritionWidgetByID200ResponseBadInner.md)
 - [Model.GetRecipeNutritionWidgetByID200ResponseGoodInner](docs/GetRecipeNutritionWidgetByID200ResponseGoodInner.md)
 - [Model.GetRecipePriceBreakdownByID200Response](docs/GetRecipePriceBreakdownByID200Response.md)
 - [Model.GetRecipePriceBreakdownByID200ResponseIngredientsInner](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInner.md)
 - [Model.GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmount.md)
 - [Model.GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric](docs/GetRecipePriceBreakdownByID200ResponseIngredientsInnerAmountMetric.md)
 - [Model.GetRecipeTasteByID200Response](docs/GetRecipeTasteByID200Response.md)
 - [Model.GetShoppingList200Response](docs/GetShoppingList200Response.md)
 - [Model.GetShoppingList200ResponseAislesInner](docs/GetShoppingList200ResponseAislesInner.md)
 - [Model.GetShoppingList200ResponseAislesInnerItemsInner](docs/GetShoppingList200ResponseAislesInnerItemsInner.md)
 - [Model.GetShoppingList200ResponseAislesInnerItemsInnerMeasures](docs/GetShoppingList200ResponseAislesInnerItemsInnerMeasures.md)
 - [Model.GetSimilarRecipes200ResponseInner](docs/GetSimilarRecipes200ResponseInner.md)
 - [Model.GetWineDescription200Response](docs/GetWineDescription200Response.md)
 - [Model.GetWinePairing200Response](docs/GetWinePairing200Response.md)
 - [Model.GetWinePairing200ResponseProductMatchesInner](docs/GetWinePairing200ResponseProductMatchesInner.md)
 - [Model.GetWineRecommendation200Response](docs/GetWineRecommendation200Response.md)
 - [Model.GetWineRecommendation200ResponseRecommendedWinesInner](docs/GetWineRecommendation200ResponseRecommendedWinesInner.md)
 - [Model.GuessNutritionByDishName200Response](docs/GuessNutritionByDishName200Response.md)
 - [Model.GuessNutritionByDishName200ResponseCalories](docs/GuessNutritionByDishName200ResponseCalories.md)
 - [Model.GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent](docs/GuessNutritionByDishName200ResponseCaloriesConfidenceRange95Percent.md)
 - [Model.ImageAnalysisByURL200Response](docs/ImageAnalysisByURL200Response.md)
 - [Model.ImageAnalysisByURL200ResponseCategory](docs/ImageAnalysisByURL200ResponseCategory.md)
 - [Model.ImageAnalysisByURL200ResponseNutrition](docs/ImageAnalysisByURL200ResponseNutrition.md)
 - [Model.ImageAnalysisByURL200ResponseNutritionCalories](docs/ImageAnalysisByURL200ResponseNutritionCalories.md)
 - [Model.ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent](docs/ImageAnalysisByURL200ResponseNutritionCaloriesConfidenceRange95Percent.md)
 - [Model.ImageAnalysisByURL200ResponseRecipesInner](docs/ImageAnalysisByURL200ResponseRecipesInner.md)
 - [Model.ImageClassificationByURL200Response](docs/ImageClassificationByURL200Response.md)
 - [Model.IngredientSearch200Response](docs/IngredientSearch200Response.md)
 - [Model.IngredientSearch200ResponseResultsInner](docs/IngredientSearch200ResponseResultsInner.md)
 - [Model.MapIngredientsToGroceryProducts200ResponseInner](docs/MapIngredientsToGroceryProducts200ResponseInner.md)
 - [Model.MapIngredientsToGroceryProducts200ResponseInnerProductsInner](docs/MapIngredientsToGroceryProducts200ResponseInnerProductsInner.md)
 - [Model.MapIngredientsToGroceryProductsRequest](docs/MapIngredientsToGroceryProductsRequest.md)
 - [Model.ParseIngredients200ResponseInner](docs/ParseIngredients200ResponseInner.md)
 - [Model.ParseIngredients200ResponseInnerEstimatedCost](docs/ParseIngredients200ResponseInnerEstimatedCost.md)
 - [Model.ParseIngredients200ResponseInnerNutrition](docs/ParseIngredients200ResponseInnerNutrition.md)
 - [Model.ParseIngredients200ResponseInnerNutritionCaloricBreakdown](docs/ParseIngredients200ResponseInnerNutritionCaloricBreakdown.md)
 - [Model.ParseIngredients200ResponseInnerNutritionNutrientsInner](docs/ParseIngredients200ResponseInnerNutritionNutrientsInner.md)
 - [Model.ParseIngredients200ResponseInnerNutritionPropertiesInner](docs/ParseIngredients200ResponseInnerNutritionPropertiesInner.md)
 - [Model.ParseIngredients200ResponseInnerNutritionWeightPerServing](docs/ParseIngredients200ResponseInnerNutritionWeightPerServing.md)
 - [Model.QuickAnswer200Response](docs/QuickAnswer200Response.md)
 - [Model.SearchAllFood200Response](docs/SearchAllFood200Response.md)
 - [Model.SearchAllFood200ResponseSearchResultsInner](docs/SearchAllFood200ResponseSearchResultsInner.md)
 - [Model.SearchAllFood200ResponseSearchResultsInnerResultsInner](docs/SearchAllFood200ResponseSearchResultsInnerResultsInner.md)
 - [Model.SearchCustomFoods200Response](docs/SearchCustomFoods200Response.md)
 - [Model.SearchCustomFoods200ResponseCustomFoodsInner](docs/SearchCustomFoods200ResponseCustomFoodsInner.md)
 - [Model.SearchFoodVideos200Response](docs/SearchFoodVideos200Response.md)
 - [Model.SearchFoodVideos200ResponseVideosInner](docs/SearchFoodVideos200ResponseVideosInner.md)
 - [Model.SearchGroceryProducts200Response](docs/SearchGroceryProducts200Response.md)
 - [Model.SearchGroceryProductsByUPC200Response](docs/SearchGroceryProductsByUPC200Response.md)
 - [Model.SearchGroceryProductsByUPC200ResponseIngredientsInner](docs/SearchGroceryProductsByUPC200ResponseIngredientsInner.md)
 - [Model.SearchGroceryProductsByUPC200ResponseNutrition](docs/SearchGroceryProductsByUPC200ResponseNutrition.md)
 - [Model.SearchGroceryProductsByUPC200ResponseServings](docs/SearchGroceryProductsByUPC200ResponseServings.md)
 - [Model.SearchMenuItems200Response](docs/SearchMenuItems200Response.md)
 - [Model.SearchMenuItems200ResponseMenuItemsInner](docs/SearchMenuItems200ResponseMenuItemsInner.md)
 - [Model.SearchRecipes200Response](docs/SearchRecipes200Response.md)
 - [Model.SearchRecipes200ResponseResultsInner](docs/SearchRecipes200ResponseResultsInner.md)
 - [Model.SearchRecipesByIngredients200ResponseInner](docs/SearchRecipesByIngredients200ResponseInner.md)
 - [Model.SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner](docs/SearchRecipesByIngredients200ResponseInnerMissedIngredientsInner.md)
 - [Model.SearchRecipesByNutrients200ResponseInner](docs/SearchRecipesByNutrients200ResponseInner.md)
 - [Model.SearchRestaurants200Response](docs/SearchRestaurants200Response.md)
 - [Model.SearchRestaurants200ResponseRestaurantsInner](docs/SearchRestaurants200ResponseRestaurantsInner.md)
 - [Model.SearchRestaurants200ResponseRestaurantsInnerAddress](docs/SearchRestaurants200ResponseRestaurantsInnerAddress.md)
 - [Model.SearchRestaurants200ResponseRestaurantsInnerLocalHours](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHours.md)
 - [Model.SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational](docs/SearchRestaurants200ResponseRestaurantsInnerLocalHoursOperational.md)
 - [Model.SearchSiteContent200Response](docs/SearchSiteContent200Response.md)
 - [Model.SearchSiteContent200ResponseArticlesInner](docs/SearchSiteContent200ResponseArticlesInner.md)
 - [Model.SearchSiteContent200ResponseGroceryProductsInner](docs/SearchSiteContent200ResponseGroceryProductsInner.md)
 - [Model.SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner](docs/SearchSiteContent200ResponseGroceryProductsInnerDataPointsInner.md)
 - [Model.SummarizeRecipe200Response](docs/SummarizeRecipe200Response.md)
 - [Model.TalkToChatbot200Response](docs/TalkToChatbot200Response.md)


<a id="documentation-for-authorization"></a>
## Documentation for Authorization


Authentication schemes defined for the API:
<a id="apiKeyScheme"></a>
### apiKeyScheme

- **Type**: API key
- **API key parameter name**: x-api-key
- **Location**: HTTP header

