/*
 * spoonacular API
 *
 * The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.  Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.
 *
 * The version of the OpenAPI document: 1.1
 * Contact: mail@spoonacular.com
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = spoonacular.Client.OpenAPIDateConverter;

namespace spoonacular.Model
{
    /// <summary>
    /// ConvertAmounts200Response
    /// </summary>
    [DataContract(Name = "convertAmounts_200_response")]
    public partial class ConvertAmounts200Response : IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="ConvertAmounts200Response" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected ConvertAmounts200Response() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="ConvertAmounts200Response" /> class.
        /// </summary>
        /// <param name="sourceAmount">sourceAmount (required).</param>
        /// <param name="sourceUnit">sourceUnit (required).</param>
        /// <param name="targetAmount">targetAmount (required).</param>
        /// <param name="targetUnit">targetUnit (required).</param>
        /// <param name="answer">answer (required).</param>
        public ConvertAmounts200Response(decimal sourceAmount = default(decimal), string sourceUnit = default(string), decimal targetAmount = default(decimal), string targetUnit = default(string), string answer = default(string))
        {
            this.SourceAmount = sourceAmount;
            // to ensure "sourceUnit" is required (not null)
            if (sourceUnit == null)
            {
                throw new ArgumentNullException("sourceUnit is a required property for ConvertAmounts200Response and cannot be null");
            }
            this.SourceUnit = sourceUnit;
            this.TargetAmount = targetAmount;
            // to ensure "targetUnit" is required (not null)
            if (targetUnit == null)
            {
                throw new ArgumentNullException("targetUnit is a required property for ConvertAmounts200Response and cannot be null");
            }
            this.TargetUnit = targetUnit;
            // to ensure "answer" is required (not null)
            if (answer == null)
            {
                throw new ArgumentNullException("answer is a required property for ConvertAmounts200Response and cannot be null");
            }
            this.Answer = answer;
        }

        /// <summary>
        /// Gets or Sets SourceAmount
        /// </summary>
        [DataMember(Name = "sourceAmount", IsRequired = true, EmitDefaultValue = true)]
        public decimal SourceAmount { get; set; }

        /// <summary>
        /// Gets or Sets SourceUnit
        /// </summary>
        [DataMember(Name = "sourceUnit", IsRequired = true, EmitDefaultValue = true)]
        public string SourceUnit { get; set; }

        /// <summary>
        /// Gets or Sets TargetAmount
        /// </summary>
        [DataMember(Name = "targetAmount", IsRequired = true, EmitDefaultValue = true)]
        public decimal TargetAmount { get; set; }

        /// <summary>
        /// Gets or Sets TargetUnit
        /// </summary>
        [DataMember(Name = "targetUnit", IsRequired = true, EmitDefaultValue = true)]
        public string TargetUnit { get; set; }

        /// <summary>
        /// Gets or Sets Answer
        /// </summary>
        [DataMember(Name = "answer", IsRequired = true, EmitDefaultValue = true)]
        public string Answer { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class ConvertAmounts200Response {\n");
            sb.Append("  SourceAmount: ").Append(SourceAmount).Append("\n");
            sb.Append("  SourceUnit: ").Append(SourceUnit).Append("\n");
            sb.Append("  TargetAmount: ").Append(TargetAmount).Append("\n");
            sb.Append("  TargetUnit: ").Append(TargetUnit).Append("\n");
            sb.Append("  Answer: ").Append(Answer).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            // SourceUnit (string) minLength
            if (this.SourceUnit != null && this.SourceUnit.Length < 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for SourceUnit, length must be greater than 1.", new [] { "SourceUnit" });
            }

            // TargetUnit (string) minLength
            if (this.TargetUnit != null && this.TargetUnit.Length < 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for TargetUnit, length must be greater than 1.", new [] { "TargetUnit" });
            }

            // Answer (string) minLength
            if (this.Answer != null && this.Answer.Length < 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Answer, length must be greater than 1.", new [] { "Answer" });
            }

            yield break;
        }
    }

}
