/*
 * spoonacular API
 *
 * The spoonacular Nutrition, Recipe, and Food API allows you to access over thousands of recipes, thousands of ingredients, 800,000 food products, over 100,000 menu items, and restaurants. Our food ontology and semantic recipe search engine makes it possible to search for recipes using natural language queries, such as \"gluten free brownies without sugar\" or \"low fat vegan cupcakes.\" You can automatically calculate the nutritional information for any recipe, analyze recipe costs, visualize ingredient lists, find recipes for what's in your fridge, find recipes based on special diets, nutritional requirements, or favorite ingredients, classify recipes into types and cuisines, convert ingredient amounts, or even compute an entire meal plan. With our powerful API, you can create many kinds of food and especially nutrition apps.  Special diets/dietary requirements currently available include: vegan, vegetarian, pescetarian, gluten free, grain free, dairy free, high protein, whole 30, low sodium, low carb, Paleo, ketogenic, FODMAP, and Primal.
 *
 * The version of the OpenAPI document: 1.1
 * Contact: mail@spoonacular.com
 * Generated by: https://github.com/openapitools/openapi-generator.git
 */


using System;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Linq;
using System.IO;
using System.Runtime.Serialization;
using System.Text;
using System.Text.RegularExpressions;
using Newtonsoft.Json;
using Newtonsoft.Json.Converters;
using Newtonsoft.Json.Linq;
using System.ComponentModel.DataAnnotations;
using OpenAPIDateConverter = spoonacular.Client.OpenAPIDateConverter;

namespace spoonacular.Model
{
    /// <summary>
    /// GetIngredientSubstitutes200Response
    /// </summary>
    [DataContract(Name = "getIngredientSubstitutes_200_response")]
    public partial class GetIngredientSubstitutes200Response : IValidatableObject
    {
        /// <summary>
        /// Initializes a new instance of the <see cref="GetIngredientSubstitutes200Response" /> class.
        /// </summary>
        [JsonConstructorAttribute]
        protected GetIngredientSubstitutes200Response() { }
        /// <summary>
        /// Initializes a new instance of the <see cref="GetIngredientSubstitutes200Response" /> class.
        /// </summary>
        /// <param name="ingredient">ingredient (required).</param>
        /// <param name="substitutes">substitutes (required).</param>
        /// <param name="message">message (required).</param>
        public GetIngredientSubstitutes200Response(string ingredient = default(string), List<string> substitutes = default(List<string>), string message = default(string))
        {
            // to ensure "ingredient" is required (not null)
            if (ingredient == null)
            {
                throw new ArgumentNullException("ingredient is a required property for GetIngredientSubstitutes200Response and cannot be null");
            }
            this.Ingredient = ingredient;
            // to ensure "substitutes" is required (not null)
            if (substitutes == null)
            {
                throw new ArgumentNullException("substitutes is a required property for GetIngredientSubstitutes200Response and cannot be null");
            }
            this.Substitutes = substitutes;
            // to ensure "message" is required (not null)
            if (message == null)
            {
                throw new ArgumentNullException("message is a required property for GetIngredientSubstitutes200Response and cannot be null");
            }
            this.Message = message;
        }

        /// <summary>
        /// Gets or Sets Ingredient
        /// </summary>
        [DataMember(Name = "ingredient", IsRequired = true, EmitDefaultValue = true)]
        public string Ingredient { get; set; }

        /// <summary>
        /// Gets or Sets Substitutes
        /// </summary>
        [DataMember(Name = "substitutes", IsRequired = true, EmitDefaultValue = true)]
        public List<string> Substitutes { get; set; }

        /// <summary>
        /// Gets or Sets Message
        /// </summary>
        [DataMember(Name = "message", IsRequired = true, EmitDefaultValue = true)]
        public string Message { get; set; }

        /// <summary>
        /// Returns the string presentation of the object
        /// </summary>
        /// <returns>String presentation of the object</returns>
        public override string ToString()
        {
            StringBuilder sb = new StringBuilder();
            sb.Append("class GetIngredientSubstitutes200Response {\n");
            sb.Append("  Ingredient: ").Append(Ingredient).Append("\n");
            sb.Append("  Substitutes: ").Append(Substitutes).Append("\n");
            sb.Append("  Message: ").Append(Message).Append("\n");
            sb.Append("}\n");
            return sb.ToString();
        }

        /// <summary>
        /// Returns the JSON string presentation of the object
        /// </summary>
        /// <returns>JSON string presentation of the object</returns>
        public virtual string ToJson()
        {
            return Newtonsoft.Json.JsonConvert.SerializeObject(this, Newtonsoft.Json.Formatting.Indented);
        }

        /// <summary>
        /// To validate all properties of the instance
        /// </summary>
        /// <param name="validationContext">Validation context</param>
        /// <returns>Validation Result</returns>
        IEnumerable<System.ComponentModel.DataAnnotations.ValidationResult> IValidatableObject.Validate(ValidationContext validationContext)
        {
            // Ingredient (string) minLength
            if (this.Ingredient != null && this.Ingredient.Length < 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Ingredient, length must be greater than 1.", new [] { "Ingredient" });
            }

            // Message (string) minLength
            if (this.Message != null && this.Message.Length < 1)
            {
                yield return new System.ComponentModel.DataAnnotations.ValidationResult("Invalid value for Message, length must be greater than 1.", new [] { "Message" });
            }

            yield break;
        }
    }

}
